========
PyLaymon
========


.. image:: https://img.shields.io/pypi/v/laymon.svg
        :target: https://pypi.python.org/pypi/laymon

.. image:: https://readthedocs.org/projects/laymon/badge/?version=latest
        :target: https://laymon.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status



A package for monitoring and visualizing the layers of a neural network. The motivation behind the project was to provide a tool that can help developers provide a better insight into the different layers of a neural network during the training process. Currently, the package provides the functionality to observe and envision the feature maps of a neural network. For more information refer to the documentation.

Requirements
------------

* pytorch
* matplotlib

Installation
------------

* Installation: ``pip install laymon``

For more details on installation, usage and contribution refer to the documentation.

* Documentation: https://laymon.readthedocs.io.


Features
--------

* Visualizing feature maps

.. image:: art/FeatureMapMonitoring.gif


Credits
-------

The boilerplate for this package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
